export const isClient = !!window.ipcRenderer; // process.env.IS_CLIENT;

const safeCall = (f: (...args: any[]) => any) => (isClient ? f : () => {});

const ipcRenderer = window.ipcRenderer;

const system = {
  closeWindow() {
    ipcRenderer.invoke('manipulate-window', { action: 'close' });
  },
  zoomWindow() {
    ipcRenderer.invoke('manipulate-window', { action: 'zoom' });
  },
  minimizeWindow() {
    ipcRenderer.invoke('manipulate-window', { action: 'minimize' });
  },
  openUrl(url: string) {
    if (!isClient) {
      window.open(url, 'blank');
      return;
    }
    ipcRenderer.invoke('open-browser', url);
  },

  storage: {
    set: safeCall((key: string, value: any) => {
      ipcRenderer.invoke('storage:set', { key, value });
    }),
    remove: safeCall((key: string) => {
      ipcRenderer.invoke('storage:remove', { key });
    }),
  },
};

export default system;
